@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::JSONAPI;
-$Mojolicious::Plugin::JSONAPI::VERSION = '0.8';
+$Mojolicious::Plugin::JSONAPI::VERSION = '0.9';
 use Mojo::Base 'Mojolicious::Plugin';
 
 use JSONAPI::Document;
@@ -158,7 +158,9 @@ sub create_request_helpers {
     $app->helper(
         requested_resources => sub {
             my ($c) = @_;
-            my @include = split(',', $c->param('include') // '');
+            my $param = $c->param('include') // '';
+            $param =~ s/-/_/g;
+            my @include = split(',', $param);
             return \@include;
         }
     );
@@ -176,7 +178,7 @@ Mojolicious::Plugin::JSONAPI - Mojolicious Plugin for building JSON API complian
 
 =head1 VERSION
 
-version 0.8
+version 0.9
 
 =head1 SYNOPSIS
 
